<?php

// Fetch the skin path

$tmp_path = "gfx/skin/$conf_skin/gfx";

$gfx_content_background = ' bgcolor="#9FC8D7" ';

// This is the colors of the fields
$gfx_form_entry_label_background = " class=\"alternatecolorline\" ";
$gfx_form_entry_label_control_background = " class=\"alternatecolorline\" ";

$gfx_form_entry_label_alt_background = " ";
$gfx_form_entry_label_alt_control_background = " ";

// These are paths to icons
$gfx_icn_path_generate_pass = "$tmp_path/buttons/btn_generatepass.gif";
$gfx_icn_path_seepass = "$tmp_path/buttons/btn_seepass.gif";
$gfx_icn_path_add = "$tmp_path/buttons/btn_p_add.gif";
$gfx_icn_path_delete = "$tmp_path/buttons/btn_p_delete.gif";
$gfx_icn_path_editme = "$tmp_path/buttons/btn_p_edit.gif";
$gfx_icn_path_compress = "$tmp_path/buttons/btn_p_compress.gif";
$gfx_icn_path_ok = "$tmp_path/buttons/btn_p_ok.gif";
$gfx_icn_path_help = "$tmp_path/buttons/btn_help.gif";

?>